import os

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/{{ docs_version }}/howto/deployment/checklist/


# Application definition
INSTALLED_APPS = [
    'tests',
    'wagtail_airtable',

    'wagtail.contrib.forms',
    'wagtail.contrib.redirects',
    'wagtail.embeds',
    'wagtail.sites',
    'wagtail.users',
    'wagtail.snippets',
    'wagtail.documents',
    'wagtail.images',
    'wagtail.search',
    'wagtail.admin',
    'wagtail',

    'modelcluster',
    'taggit',

    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
]

MIDDLEWARE = [
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'django.middleware.security.SecurityMiddleware',

    'wagtail.contrib.redirects.middleware.RedirectMiddleware',
]

ROOT_URLCONF = 'tests.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'tests.wsgi.application'


# Database
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'test-db.sqlite3'),
    }
}

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]

PASSWORD_HASHERS = (
    'django.contrib.auth.hashers.MD5PasswordHasher',  # don't use the intentionally slow default password hasher
)

LANGUAGE_CODE = 'en-us'
TIME_ZONE = 'UTC'
USE_I18N = True
USE_L10N = True
USE_TZ = True


STATICFILES_FINDERS = [
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
]

STATIC_ROOT = os.path.join(BASE_DIR, 'static')
STATIC_URL = '/static/'

MEDIA_ROOT = os.path.join(BASE_DIR, 'test-media')
MEDIA_URL = 'http://media.example.com/media/'

SECRET_KEY = 'not needed'

# Wagtail settings

WAGTAIL_SITE_NAME = "wagtail-airtable"
WAGTAILADMIN_BASE_URL = 'http://example.com'

AIRTABLE_API_KEY = 'keyWoWoWoWoW'
WAGTAIL_AIRTABLE_ENABLED = True
WAGTAIL_AIRTABLE_DEBUG = False
AIRTABLE_IMPORT_SETTINGS = {
    'tests.SimplePage': {
        'AIRTABLE_BASE_KEY': 'xxx',
        'AIRTABLE_TABLE_NAME': 'xxx',
        'AIRTABLE_UNIQUE_IDENTIFIER': 'slug',
        'AIRTABLE_SERIALIZER': 'tests.serializers.SimplePageSerializer',
    },
    'tests.Advert': {
        'AIRTABLE_BASE_KEY': 'app_airtable_advert_base_key',
        'AIRTABLE_TABLE_NAME': 'Advert Table Name',
        'AIRTABLE_UNIQUE_IDENTIFIER': 'slug',
        'AIRTABLE_SERIALIZER': 'tests.serializers.AdvertSerializer',
        'AIRTABLE_BASE_URL': 'https://airtable.com/tblxXxXxXxXx/viwXxXxXXxXXx'
    },
    'tests.SimilarToAdvert': {  # Exact same as 'tests.Advert'
        'AIRTABLE_BASE_KEY': 'app_airtable_advert_base_key',
        'AIRTABLE_TABLE_NAME': 'Advert Table Name',
        'AIRTABLE_UNIQUE_IDENTIFIER': 'slug',
        'AIRTABLE_SERIALIZER': 'tests.serializers.AdvertSerializer',
        'AIRTABLE_BASE_URL': 'https://airtable.com/tblxXxXxXxXx/viwXxXxXXxXXx'
    },
}

DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
